==> meecrowave-1.2.13-source-release.zip: meecrowave-1.2.13/meecrowave-junit/src/test/java/org/app/Endpoint.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.app;

import javax.enterprise.context.ApplicationScoped;
import javax.inject.Inject;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;

@Path("test")
@ApplicationScoped
public class Endpoint {
    @Inject
    private Injectable injectable;

    @GET
    @Produces(MediaType.TEXT_PLAIN)
    public String simple() {
        return Boolean.parseBoolean(injectable.injected()) ? "simple" : "fail";
    }

    @GET
    @Path("json")
    @Produces(MediaType.APPLICATION_JSON)
    public Simple json() {
        return new Simple("test");
    }

    public static class Simple {
        private String name;

        public Simple() {
            // no-op
        }

        public Simple(final String name) {
            this.name = name;
        }

        public String getName() {
            return name;
        }

        public void setName(final String name) {
            this.name = name;
        }
    }
}

==> meecrowave-2.0.0-source-release.zip: meecrowave-2.0.0/meecrowave-junit/src/test/java/org/app/Endpoint.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.app;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.inject.Inject;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.MediaType;

@Path("test")
@ApplicationScoped
public class Endpoint {
    @Inject
    private Injectable injectable;

    @GET
    @Produces(MediaType.TEXT_PLAIN)
    public String simple() {
        return Boolean.parseBoolean(injectable.injected()) ? "simple" : "fail";
    }

    @GET
    @Path("json")
    @Produces(MediaType.APPLICATION_JSON)
    public Simple json() {
        return new Simple("test");
    }

    public static class Simple {
        private String name;

        public Simple() {
            // no-op
        }

        public Simple(final String name) {
            this.name = name;
        }

        public String getName() {
            return name;
        }

        public void setName(final String name) {
            this.name = name;
        }
    }
}
